---
title: '[2024년8월] 서비스이용약관 및 개인정보처리방침 개정 변경 안내'
category: 공지사항
tags:
  - 공지사항
searchTags:
  - 개인정보처리방침
  - 이용약관
datetime: 2024-08-02T01:40:56.375Z
---

안녕하세요\~! 포트원 입니다.

항상 포트원을 이용해주시는 고객 여러분께 진심으로 감사드립니다.

2024년 09월 02일 아래와 같이 서비스이용약관 및 개인정보처리방침이 변경됨을 사전 안내 드립니다.

- 공지일 : 2024.08.02(금)
- 시행일 : 2024.09.02(월)

<Highlight text="[서비스이용약관] 변경 및 추가내용" />

<Accordion title="▶ 서비스의 내용 (변경)" image="https://help.portone.io/uploads/포트원소식/서비스의내용.png" />

<Accordion title="▶ 약관의 명시, 효력과 개정 (추가)" content="<>

</>" image="https://help.portone.io/uploads/포트원소식/약관의 명시, 효력과 개정.png" />

<Accordion title="▶ 서비스별 이용요금 (변경)" image="https://help.portone.io/uploads/포트원소식/서비스별 이용요금.png" />

<Accordion title="▶ 이용요금의 청구 및 지급 (추가) " image="https://help.portone.io/uploads/포트원소식/이용요금의 청구 및 지급.png" />

<Accordion title="▶ 서비스의 중단 (변경)" image="https://help.portone.io/uploads/포트원소식/서비스의 중단.png" />

<Accordion title="▶ 조항 순서 (변경)" image="https://help.portone.io/uploads/포트원소식/조항순서 변경 1.png" />

<Accordion title="▶ 개인정보보호 (변경)" image="https://help.portone.io/uploads/포트원소식/개인정보보호.png" />

<Accordion title="▶ 손해배상 (변경)" image="https://help.portone.io/uploads/포트원소식/손해배상.png" />

<Accordion title="▶ 제3장 &quot;원 페이먼트 인프라(One Payment Infra)서비스&quot;이용에 관한 특칙 (추가)" image="https://help.portone.io/uploads/포트원소식/제3장 OPI 서비스 특칙.png" />

<Accordion title="▶ 유료플랜 전환  (추가)" image="https://help.portone.io/uploads/포트원소식/유료플랜 전환.png" />

<Accordion title="▶ 유료플랜 이용요금의 계산 (추가)" image="https://help.portone.io/uploads/포트원소식/이용요금의 계산 수정.png" />

<Accordion title="▶ 유료플랜 이용요금의 청구 및 납입 (추가)" image="https://help.portone.io/uploads/포트원소식/유료플랜 이용요금의 청구 및 납입.png" />

<Accordion title="▶ 유료플랜 이용요금에 대한 이의신청 및 반환 (추가)" image="https://help.portone.io/uploads/포트원소식/유료플랜 이용요금에 대한 이의신청 및 반환.png" />

<Accordion title="▶ 유료플랜 약정할인 위약금 (추가)" image="https://help.portone.io/uploads/포트원소식/유료플랜 약정할인 위약금.png" />

<Highlight text="[개인정보처리방침] 변경 및 추가내용" />

<Accordion title="▶ 수집하는 개인정보의 항목 (변경)" image="https://help.portone.io/uploads/포트원소식/수집하는 개인정보의 항목.png" />

<Accordion title="▶ 개인정보 처리의 위탁 (변경)" content="<>

</>" image="https://help.portone.io/uploads/포트원소식/개인정보 처리의 위탁.png" />

<Accordion title="▶ 개인정보 국외이전 (추가)" content="<>

</>" image="https://help.portone.io/uploads/포트원소식/개인정보 국외이전.png" />

[기존 서비스이용약관 보러가기 ↗](https://terms.portone.io)

[기존 개인정보처리방침 보러가기 ↗](https://privacy.portone.io)
